@@ -190,8 +190,8 @@ def basicSafetyStock(file,productNumber,safetyDays,leadTimeinDays):
     avg_sales = sales_qty.quantity.mean()
     safety_stock = avg_sales*safetyDays
     reorder_point = safety_stock+avg_sales*leadTimeinDays
-    print("Safety Stock: "+str(safety_stock))
-    print("Reorder Point: "+str(reorder_point))
+    print("Safety Stock: "+str(safety_stock.round(2)))
+    print("Reorder Point: "+str(reorder_point.round(2)))
     
 def safetyStockwtServiceRate(file,productNumber,serviceRate,leadTimeInDays):
     sales = pd.read_csv(file)
@@ -204,10 +204,32 @@ def safetyStockwtServiceRate(file,productNumber,serviceRate,leadTimeInDays):
     sales_qty = sales_qty.reset_index()
     sales_qty = sales_qty[['quantity']]
     avg_sales = sales_qty.quantity.mean()
-    std = sales_qty.std()
+    std = sales_qty.quantity.std()
     servZ = norm.ppf(serviceRate)
     LT_sqrt = math.sqrt(leadTimeInDays/30)
     safety_stock = servZ*std*LT_sqrt
     reorder_point = safety_stock+avg_sales*leadTimeInDays
-    print("Safety Stock: "+str(safety_stock))
-    print("Reorder Point: "+str(reorder_point))
\ No newline at end of file
+    print("Safety Stock: "+str(safety_stock.round(2)))
+    print("Reorder Point: "+str(reorder_point.round(2)))
+    
+def safetyStockwtServiceRateList(file,serviceRate,leadTimeInDays):
+    sales = pd.read_csv(file)
+    sales['ref'] = sales['ref'].astype('category')
+    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
+    sales['product_number'] = sales['product_number'].astype('category')
+    sales['product_name'] = sales['product_name'].astype('category')
+    result = pd.DataFrame(columns=['product_number', 'product_name', 'safety_stock', 'reorder_point'])
+    for pnum in sales.product_number.unique():
+        sales_prep = sales.loc[sales['product_number'] == pnum]
+        sales_qty = sales_prep.set_index(["date"])
+        sales_qty = sales_qty.reset_index()
+        sales_qty = sales_qty[['quantity']]
+        avg_sales = sales_qty.quantity.mean()
+        std = sales_qty.quantity.std()
+        servZ = norm.ppf(serviceRate)
+        LT_sqrt = math.sqrt(leadTimeInDays/30)
+        safety_stock = servZ*std*LT_sqrt
+        reorder_point = safety_stock+avg_sales*leadTimeInDays
+        result = result.append({'product_number': pnum, 'product_name': sales_prep['product_name'].iloc[0], 'safety_stock': safety_stock.round(2), 'reorder_point':reorder_point.round(2)}, ignore_index=True)
+    result.to_csv('ServiceRateSafetyStock.csv', index = False)
+    print("Saftey Stock with service rate method method", result, sep='\n')
\ No newline at end of file
